==> seedsui-react-5.8.44.tgz: package/lib/DatePicker/RangeMain/index.js <==
var _excluded = ["visible", "portal", "SelectorProps", "allowClear", "value", "onBeforeChange", "onChange", "defaultPickerValue", "titles", "disabledStart", "disabledEnd", "min", "max", "type", "onError", "ranges", "DatePickerModalProps", "customModal"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import SelectorMain from "./SelectorMain";
import defaultRanges from "./SelectorMain/defaultRanges";
import PickerMain from "./PickerMain";

// 日期快捷选择
function RangeMain(_ref, ref) {
  var visible = _ref.visible,
    portal = _ref.portal,
    SelectorProps = _ref.SelectorProps,
    allowClear = _ref.allowClear,
    value = _ref.value,
    onBeforeChange = _ref.onBeforeChange,
    onChange = _ref.onChange,
    defaultPickerValue = _ref.defaultPickerValue,
    titles = _ref.titles,
    disabledStart = _ref.disabledStart,
    disabledEnd = _ref.disabledEnd,
    min = _ref.min,
    max = _ref.max,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? 'date' : _ref$type,
    onError = _ref.onError,
    _ref$ranges = _ref.ranges,
    ranges = _ref$ranges === void 0 ? defaultRanges : _ref$ranges,
    DatePickerModalProps = _ref.DatePickerModalProps,
    _ref$customModal = _ref.customModal,
    customModal = _ref$customModal === void 0 ? 'dates' : _ref$customModal,
    props = _objectWithoutProperties(_ref, _excluded);
  // 判断有没有快捷选择
  var hasSelector = false;
  // 限制天数
  var dateRangeLimit = null;
  if (ranges) {
    for (var key in ranges) {
      if (Array.isArray(ranges[key])) {
        hasSelector = true;
      } else if (typeof ranges[key] === 'number') {
        dateRangeLimit = ranges[key];
      }
    }
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, hasSelector && /*#__PURE__*/React.createElement(SelectorMain, _extends({
    ref: ref,
    portal: portal,
    type: type,
    min: min,
    max: max,
    disabledStart: disabledStart,
    disabledEnd: disabledEnd,
    allowClear: allowClear,
    value: value,
    defaultPickerValue: defaultPickerValue,
    onBeforeChange: onBeforeChange,
    onChange: onChange,
    onError: onError,
    SelectorProps: SelectorProps,
    DatePickerModalProps: DatePickerModalProps,
    titles: titles,
    ranges: ranges,
    customModal: customModal
  }, props)), !hasSelector && /*#__PURE__*/React.createElement(PickerMain, _extends({
    ref: ref,
    portal: portal,
    type: type,
    min: min,
    max: max,
    disabledStart: disabledStart,
    disabledEnd: disabledEnd,
    dateRangeLimit: dateRangeLimit,
    allowClear: allowClear,
    value: value,
    defaultPickerValue: defaultPickerValue,
    onBeforeChange: onBeforeChange,
    onChange: onChange,
    onError: onError
  }, props)));
}
export default /*#__PURE__*/forwardRef(RangeMain);

==> seedsui-react-5.8.79.tgz: package/lib/DatePicker/RangeMain/index.js <==
var _excluded = ["visible", "value", "type", "min", "max", "disabledStart", "disabledEnd", "allowClear", "onChange", "rangeId", "ranges", "titles", "portal", "SelectorProps", "DatePickerModalProps"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import SelectorMain from "./SelectorMain";
import defaultRanges from "./defaultRanges";
import PickerMain from "./PickerMain";

// 日期快捷选择
function RangeMain(_ref, ref) {
  var visible = _ref.visible,
    value = _ref.value,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? 'date' : _ref$type,
    min = _ref.min,
    max = _ref.max,
    disabledStart = _ref.disabledStart,
    disabledEnd = _ref.disabledEnd,
    allowClear = _ref.allowClear,
    onChange = _ref.onChange,
    rangeId = _ref.rangeId,
    _ref$ranges = _ref.ranges,
    ranges = _ref$ranges === void 0 ? defaultRanges : _ref$ranges,
    titles = _ref.titles,
    portal = _ref.portal,
    SelectorProps = _ref.SelectorProps,
    DatePickerModalProps = _ref.DatePickerModalProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 判断有没有快捷选择
  var hasSelector = false;
  if (ranges) {
    for (var key in ranges) {
      if (Array.isArray(ranges[key])) {
        hasSelector = true;
      }
    }
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, hasSelector && /*#__PURE__*/React.createElement(SelectorMain, _extends({
    ref: ref,
    portal: portal,
    type: type,
    min: min,
    max: max,
    disabledStart: disabledStart,
    disabledEnd: disabledEnd,
    allowClear: allowClear,
    value: value,
    onChange: onChange,
    SelectorProps: SelectorProps,
    DatePickerModalProps: DatePickerModalProps,
    titles: titles,
    rangeId: rangeId,
    ranges: ranges
  }, props)), !hasSelector && /*#__PURE__*/React.createElement(PickerMain, _extends({
    ref: ref,
    portal: portal,
    type: type,
    min: min,
    max: max,
    disabledStart: disabledStart,
    disabledEnd: disabledEnd,
    allowClear: allowClear,
    value: value,
    onChange: onChange
  }, props)));
}
export default /*#__PURE__*/forwardRef(RangeMain);
